"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([[4657],{

/***/ 34657:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   createArchitectureServices: () => (/* reexport safe */ _chunk_UMXZTB3W_mjs__WEBPACK_IMPORTED_MODULE_0__.i)
/* harmony export */ });
/* harmony import */ var _chunk_UMXZTB3W_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(54756);
/* harmony import */ var _chunk_TCCFYFTB_mjs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(68742);





/***/ })

}]);
//# sourceMappingURL=4657.42e4191d7d5ce671328d.js.map?v=42e4191d7d5ce671328d